command

package module
v0.1.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 26, 2026 License: MIT Imports: 3 Imported by: 0

README

Documentation

Index

Examples

Constants

const (
	CatNumberLines   catNumberLinesFlag = true
	CatNoNumberLines catNumberLinesFlag = false
)
const (
	CatNumberNonBlank   catNumberNonBlankFlag = true
	CatNoNumberNonBlank catNumberNonBlankFlag = false
)

Variables

This section is empty.

Functions

func Cat

func Cat(opts ...any) gloo.Command[[]byte, []byte]

Cat returns a Command that concatenates input to output with optional line numbering.

Flags:

  • CatNumberLines (-n): number all output lines
  • CatNumberNonBlank (-b): number non-blank lines only (overrides -n)
Example
package main

import (
	"fmt"

	"github.com/gloo-foo/testable"

	command "github.com/gloo-foo/cmd-cat"
)

func main() {
	lines, _ := testable.TestLines(command.Cat(), "hello\nworld\n")
	for _, line := range lines {
		fmt.Println(line)
	}
}
Output:
hello
world
Example (NumberLines)
package main

import (
	"fmt"

	"github.com/gloo-foo/testable"

	command "github.com/gloo-foo/cmd-cat"
)

func main() {
	lines, _ := testable.TestLines(command.Cat(command.CatNumberLines), "hello\nworld\n")
	for _, line := range lines {
		fmt.Println(line)
	}
}
Output:
     1	hello
     2	world

Types

This section is empty.

Directories

Path Synopsis
Package alias provides unprefixed names for cat command flags.
Package alias provides unprefixed names for cat command flags.

Jump to